summaryrefslogtreecommitdiffstats
path: root/source/Player.h
diff options
context:
space:
mode:
Diffstat (limited to 'source/Player.h')
-rw-r--r--source/Player.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/source/Player.h b/source/Player.h
index 5617b9785..c582c1802 100644
--- a/source/Player.h
+++ b/source/Player.h
@@ -93,11 +93,11 @@ public:
// tolua_begin
- /// Closes the current window, resets current window to m_InventoryWindow
- void CloseWindow(void);
+ /// Closes the current window, resets current window to m_InventoryWindow. A plugin may refuse the closing if a_CanRefuse is true
+ void CloseWindow(bool a_CanRefuse = true);
/// Closes the current window if it matches the specified ID, resets current window to m_InventoryWindow
- void CloseWindowIfID(char a_WindowID);
+ void CloseWindowIfID(char a_WindowID, bool a_CanRefuse = true);
cClientHandle * GetClientHandle(void) const { return m_ClientHandle; }